@@ -1,4 +1,4 @@
 from .main import install, uninstall, installed, develop
 from .init_methods import init, init_file, init_dir
-import tools
+from . import tools
 from . import config_gen
